Filings — Calcbench API Client documentation

# Filings

class calcbench.filing.Filing(**kwargs)
  CIK: str
  property accession_id: int

    same as calcbench_id, calcbench_id should have been accession_id

    Return type

      `int`

  associated_earnings_press_release_SEC_URL: str
  associated_proxy_SEC_URL: str
  calcbench_accepted: datetime.datetime
  calcbench_finished_load: datetime.datetime
  calcbench_id: int
  calendar_period: calcbench.api_query_params.Period
  calendar_year: int
  document_type: str
  entity_id: int
  entity_name: str
  filing_date: datetime.datetime
  filing_sub_type: str
  filing_type: calcbench.filing.FilingType
  fiscal_period: calcbench.api_query_params.Period
  fiscal_year: int
  is_wire: bool
  is_xbrl: bool
  link1: str
  link2: str
  link3: str
  percentage_revenue_change: Optional[float]
  period_end_date: datetime.datetime
  period_index: int
  sec_accession_id: str
  sec_html_url: str
  standardized_XBRL: bool
  this_period_revenue: Optional[float]
  ticker: str

class calcbench.filing.FilingType(value)

  An enumeration.

  BusinessWirePR_filedAfterAn8K = 'BusinessWirePR_filedAfterAn8K'
  BusinessWirePR_replaced = 'BusinessWirePR_replaced'
  Four24B = 'Four24B'
  NT10KorQ = 'NT10KorQ'
  S = 'S'
  annualQuarterlyReport = 'annualQuarterlyReport'
  commentLetter = 'commentLetter'
  commentLetterResponse = 'commentLetterResponse'
  eightk_conferenceCallTranscript = 'eightk_conferenceCallTranscript'
  eightk_earningsPressRelease = 'eightk_earningsPressRelease'
  eightk_earningsPressRelease_correction = 'eightk_earningsPressRelease_correction'
  eightk_earningsPressRelease_preliminary = 'eightk_earningsPressRelease_preliminary'
  eightk_guidanceUpdate = 'eightk_guidanceUpdate'
  eightk_monthlyOperatingMetrics = 'eightk_monthlyOperatingMetrics'
  eightk_nonfinancial = 'eightk_nonfinancial'
  eightk_other = 'eightk_other'
  eightk_presentationSlides = 'eightk_presentationSlides'
  form_3 = 'form_3'
  form_4 = 'form_4'
  form_5 = 'form_5'
  institutionalOwnsership_13F = 'institutionalOwnsership_13F'
  proxy = 'proxy'

calcbench.filing.filings(company_identifiers=[], entire_universe=False, include_non_xbrl=True, received_date=None, start_date=None, end_date=None, include_press_releases_and_proxies=True, filing_types=[])

  SEC filings

  https://www.calcbench.com/filings

  Parameters

    - company_identifiers (`Sequence`[`Union`[`str`, `int`]]) – list of tickers or CIK codes

    - received_date (`Optional`[`date`]) – get all filings received on this date

    - entire_universe (`bool`) – filings for all companies

    - include_non_xbrl (`bool`) – include filings that do not have XBRL, 8-Ks, earnings releases etc.

    - received_data – only filings published on this date

    - start_date (`Optional`[`date`]) – filings received on or after this date

    - end_date (`Optional`[`date`]) – filings received on or before theis date

    - filing_type – types of filings to include

  Usage::

        >>> from datetime import date
        >>> calcbench.filings(received_date=date.today(), entire_universe=True)

  Return type

    `Iterable`[`Filing`]

calcbench.filing.filings_dataframe(company_identifiers=[], entire_universe=False, include_non_xbrl=True, received_date=None, start_date=None, end_date=None, include_press_releases_and_proxies=True, filing_types=[])

  SEC filings in a dataframe

  https://www.calcbench.com/filings

  Parameters

    - company_identifiers (`Sequence`[`Union`[`str`, `int`]]) – list of tickers or CIK codes

    - received_date (`Optional`[`date`]) – get all filings received on this date

    - entire_universe (`bool`) – filings for all companies

    - include_non_xbrl (`bool`) – include filings that do not have XBRL, 8-Ks, earnings releases etc.

    - received_data – only filings published on this date

    - start_date (`Optional`[`date`]) – filings received on or after this date

    - end_date (`Optional`[`date`]) – filings received on or before theis date

    - filing_type – types of filings to include

  Usage::

        >>> import calcbench as cb
        >>> from calcbench.filing import FilingType
        >>> cb.filings_dataframe(
        >>>     entire_universe=True,
        >>>     filing_types=[FilingType.commentLetter, FilingType.commentLetterResponse],
        >>> )

  Return type

    `DataFrame`